@@ -48,11 +48,11 @@ namespace libsemigroups {
       using const_iterator =
           typename std::array<T, N*(N + 1) / 2>::const_iterator;
 
-      StaticTriVector2(StaticTriVector2 const&) = default;
-      StaticTriVector2(StaticTriVector2&&)      = default;
+      StaticTriVector2(StaticTriVector2 const&)            = default;
+      StaticTriVector2(StaticTriVector2&&)                 = default;
       StaticTriVector2& operator=(StaticTriVector2 const&) = default;
-      StaticTriVector2& operator=(StaticTriVector2&&) = default;
-      ~StaticTriVector2()                            = default;
+      StaticTriVector2& operator=(StaticTriVector2&&)      = default;
+      ~StaticTriVector2()                                  = default;
 
       StaticTriVector2() : _data(), _sizes() {
         clear();
@@ -135,10 +135,10 @@ namespace libsemigroups {
       using const_pointer   = typename std::vector<T, A>::const_pointer;
       using pointer         = typename std::vector<T, A>::pointer;
 
-      DynamicArray2(DynamicArray2 const&) = default;
-      DynamicArray2(DynamicArray2&&)      = default;
+      DynamicArray2(DynamicArray2 const&)            = default;
+      DynamicArray2(DynamicArray2&&)                 = default;
       DynamicArray2& operator=(DynamicArray2 const&) = default;
-      DynamicArray2& operator=(DynamicArray2&&) = default;
+      DynamicArray2& operator=(DynamicArray2&&)      = default;
 
       ~DynamicArray2() = default;
 
@@ -282,6 +282,12 @@ namespace libsemigroups {
         _vec.clear();  // noexcept
       }
 
+      void reshape(size_t nr_cols, size_t nr_rows) {
+        clear();
+        add_cols(nr_cols);
+        add_rows(nr_rows);
+      }
+
       // Throws if the assignment operator of T throws
       void shrink_rows_to(size_type n) {
         if (n < _nr_rows) {
@@ -761,10 +767,10 @@ namespace libsemigroups {
         }
       }
 
-      StaticVector1(StaticVector1 const&) = default;
-      StaticVector1(StaticVector1&&)      = default;
+      StaticVector1(StaticVector1 const&)            = default;
+      StaticVector1(StaticVector1&&)                 = default;
       StaticVector1& operator=(StaticVector1 const&) = default;
-      StaticVector1& operator=(StaticVector1&&) = default;
+      StaticVector1& operator=(StaticVector1&&)      = default;
 
       ~StaticVector1() = default;
 
@@ -897,6 +903,28 @@ namespace libsemigroups {
         return _array[pos];
       }
 
+      template <class InputIt>
+      iterator insert(const_iterator pos, InputIt first, InputIt last) {
+        size_type const M = std::distance(first, last);
+        LIBSEMIGROUPS_ASSERT(_size + M <= N);
+        LIBSEMIGROUPS_ASSERT(cend() - pos <= _array.cend() - cend());
+        // Is there a better way of initialising it?
+        iterator pos_copy = begin() + std::distance(cbegin(), pos);
+        for (iterator it = end(); it-- > pos_copy;) {
+          *(it + M) = std::move(*it);
+        }
+        iterator it = pos_copy;
+        for (auto copy = first; copy != last; ++it, ++copy) {
+          *it = *copy;
+        }
+        _size += M;
+        return it - M;
+      }
+
+      iterator insert(const_iterator pos, const_reference value) {
+        return insert(pos, &value, &value + 1);
+      }
+
      private:
       std::array<T, N> _array;
       size_t           _size;
@@ -929,11 +957,11 @@ namespace libsemigroups {
         clear();
       }
 
-      StaticVector2(StaticVector2 const&) = default;
-      StaticVector2(StaticVector2&&)      = default;
+      StaticVector2(StaticVector2 const&)            = default;
+      StaticVector2(StaticVector2&&)                 = default;
       StaticVector2& operator=(StaticVector2 const&) = default;
-      StaticVector2& operator=(StaticVector2&&) = default;
-      ~StaticVector2()                          = default;
+      StaticVector2& operator=(StaticVector2&&)      = default;
+      ~StaticVector2()                               = default;
 
       // Not noexcept since std::array::fill is not.
       void clear() {
@@ -1007,12 +1035,12 @@ namespace libsemigroups {
       friend class Array2;
 
      public:
-      Array2()              = default;
-      Array2(Array2 const&) = default;
-      Array2(Array2&&)      = default;
+      Array2()                         = default;
+      Array2(Array2 const&)            = default;
+      Array2(Array2&&)                 = default;
       Array2& operator=(Array2 const&) = default;
-      Array2& operator=(Array2&&) = default;
-      ~Array2()                   = default;
+      Array2& operator=(Array2&&)      = default;
+      ~Array2()                        = default;
 
       // Not noexcept cos std::array::fill isn't
       inline void fill(T const& value) {
